/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import java.util.stream.Stream;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

public class FileProducerStreamTest extends ContextTestSupport {

    @Test
    public void testStream() throws Exception {
        getMockEndpoint("mock:result").expectedMessageCount(1);

        Object body = Stream.of("ABC", "DEF", "1234567890");
        template.sendBodyAndHeader("direct:start", body, Exchange.FILE_NAME, "report.txt");

        assertMockEndpointsSatisfied();

        assertFileExists(testFile("report.txt"), "ABCDEF1234567890");
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:start").to(fileUri()).to("mock:result");
            }
        };
    }
}
